# Programmatic API

The programmating API is accessible via `import manifestoo`. All the rest is
private and subject to change without notice.

But... Stéphane, nothing is exposed there ?

Yes, for now there is no public programmatic API, only the CLI is documented
and has stability guarantees. If you wish to use the programmatic API, do not
hesitate to reach out via a GitHub issue, so we can work out what a good API
would look like and document it.
